#include <avr/io.h>
#include <stdlib.h>
//#include "lcd.h"
#include <fox_uart.h>

//SDA = Pin27 PC4 (Atmega8) = Pin1 (Lm75)
//SCL = Pinn28 PC5 (Atmega8) = Pin2 (Lm75)

#define TRUE 1
#define FALSE 0
#define ACK TRUE
#define NACK FALSE

#define START 0x08
#define TW_MT_SLA_ACK 0x18
#define TW_MT_DATA_ACK	0x28

void lm75_read(void);
void i2c_init(void);
int i2c_send_start(uint8_t adress);
int i2c_send_byte(uint8_t data);
void i2c_send_stop(void);
int i2c_read(uint8_t adress, uint8_t ackflag);

  struct TEMPERATUR {
  uint8_t high;
  uint8_t low;
  } temp;
  


int main(void)
{
	uint8_t nachkomma, ganzzahl;
	
	i2c_init();
	init_uart();
	
	lm75_read();
	
	

	if(bit_is_set(temp.low, 0))
		nachkomma = 5;
	else
		nachkomma = 0;
		
	temp.low >>= 1;
	temp.high <<= 7;
	ganzzahl= temp.low | temp.high;
	
	
	uart_putc('C');
	uart_intout(ganzzahl);
	uart_putc('.');
	uart_intout(nachkomma);
	uart_putc(' ');
	
	return 0;
}






void lm75_read(void)
{
  i2c_send_stop();
   i2c_send_start(0x91);  //Hier kommt die Adresse vom Temp Sensor
  temp.high = i2c_read(0x90,ACK);
  temp.low = i2c_read(0x90, NACK);
  i2c_send_stop();
}

void i2c_init(void)
{

  // IIC INIT (100kHz)
  //TWSR &= 0xfc;    // Vorteiler im IIC STATUS-REGISTER auf "1" ( TWPS1=TWPS0 = 0 )
  //TWBR = 0x0c;    // IIC BIT-RATE-Register Manual Seite 165 ( doc2486.pdf )  TWBR = ( CPU_Clock/SCL_Clock - 16) / 2
                      // TWBR = ( 4MHz/100kHz - 16) / 2 = 12 -> 0x0c

//	TWBR |= (1 << 5); //TWBR = 32 = 100 000
	TWBR = 0x08;
 

}

int i2c_send_start(uint8_t adress)
{
	TWCR |= ((1 << TWINT) | (1 << TWSTA) | (1 << TWEN)); //Sende start Condition
	while(!(TWCR & (1 << TWINT))); //Warte bis ende
	
	if((TWSR & 0xF8) != START)
		return -1;
	
	TWDR = adress;
	//TWDR = (adress | r_w);							//Adresse senden
	TWCR = (1 << TWINT) | (1 << TWEN);
	while(!(TWCR & (1 << TWINT)));
	
	if((TWCR & 0xF8) != TW_MT_SLA_ACK)
		return -1;
	
 /* //Hinzugefgt von lm75routine.c
  TWSR &= 0x02;    // Statusregister ruecksetzen
  twcr_byte= 0x00;
  twcr_byte = ((1<<TWINT)|(1<<TWSTA)|(1<<TWEN));
  TWCR=twcr_byte;
  while (!(TWCR & (1<<TWINT)));*/


	return 0;
}

int i2c_send_byte(uint8_t data)
{
	TWDR = data;
	TWCR = (1 << TWINT) | (1 << TWEN);
	
	while(!(TWCR & (1 << TWINT)));
	
	if((TWSR & 0xF8) != TW_MT_DATA_ACK)
		return -1;
		
 /* //Hinzugefgt von lm75routine.c
  TWSR &= 0x02;
  TWDR = sendbyte;
  twcr_byte= 0x00;
  twcr_byte = ((1<<TWINT) | (1<<TWEN));
  TWCR=twcr_byte;
  while (!(TWCR & (1<<TWINT)));
 */
	return 0;
}

void i2c_send_stop(void)
{
	TWCR = (1 << TWINT) | (1 << TWEN) | (1 << TWSTO);
	while(!(TWCR & (1 << TWSTO)));

 /* //Hinzugefgt von lm75routine.c
  TWSR &= 0x02;
  twcr_byte= 0x00;
  twcr_byte = ((1<<TWINT)|(1<<TWEN)|(1<<TWSTO));
  TWCR=twcr_byte;
  */
}

int i2c_read(uint8_t adress, uint8_t ackflag)
{
	if(ackflag == ACK)
		TWCR = (1 << TWINT) | (1 << TWEN) | (1 << TWEA);
	else
		TWCR = (1 << TWINT) | (1 << TWEN);
	
	while(!(TWCR & (1 << TWINT)));

 /* //Hinzugefgt von lm75routine.c
  TWSR &= 0x02;
  twcr_byte= 0x00;
  */

	return TWDR;
}


